Introduction
============

`The Comprehensive R Archive Network <https://cran.r-project.org/>`_ (CRAN) is
a repository of precompiled packages for the R statistical programming language
environment. This role can be used to enable the upstream CRAN APT repositories
and install R packages, both via APT and via R itself.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.3.0``. To install it, run:

.. code-block:: yaml

   ansible-galaxy install debops.cran

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
